@@ -8,7 +8,7 @@ import time
 """
 DropBy
 Author: Jacob Vlijm
-Copyright © 2017-2019 Ubuntu Budgie Developers
+Copyright © 2017-2020 Ubuntu Budgie Developers
 Website=https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -43,11 +43,11 @@ def get_usb():
     allvols = udev_context.list_devices(subsystem='block')
     for v in allvols:
         try:
-            uuid = v['ID_FS_UUID']
-        except KeyError:
+            uuid = v.get('ID_FS_UUID')
+        except Exception:
             pass
         else:
-            if "usb" in v["DEVPATH"]:
+            if all(["usb" in v.get("DEVPATH"), uuid]):
                 relevant.append(uuid)
     return relevant
 
@@ -60,7 +60,11 @@ def get_mounted():
     relevant = []
     mounted = psutil.disk_partitions(all=False)
     for v in mounted:
-        usage = psutil.disk_usage(v.mountpoint)
+        usage = None
+        try:
+            usage = psutil.disk_usage(v.mountpoint)
+        except PermissionError:
+            continue
         dev = v.device
         # mountpoint is relevant for possible actions
         mpoint = v.mountpoint
