@@ -3,7 +3,7 @@
 """
 Keyboard Auto Switch
 Author: Jacob Vlijm
-Copyright © 2017-2018 Ubuntu Budgie Developers
+Copyright © 2017-2020 Ubuntu Budgie Developers
 Website: https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -26,6 +26,7 @@ import time
 import subprocess
 import ast
 import psutil
+import dbus
 
 
 settingspath = os.path.join(
@@ -118,9 +119,12 @@ class KeyboardAutoSwitchApplet(Budgie.Applet):
         # initiate
         try:
             # get the possible existing dict data
-            self.langdata = ast.literal_eval(
-                open(lang_datafile).read().strip()
-            )
+            f = open(lang_datafile)
+            val = f.read()
+            if val == "":
+                raise FileNotFoundError
+            self.langdata = ast.literal_eval(val.strip())
+
         except FileNotFoundError:
             self.langdata = {}
         try:
@@ -137,6 +141,11 @@ class KeyboardAutoSwitchApplet(Budgie.Applet):
         delete_button.connect("clicked", self.remove_exception)
         self.act_on_gsettingschange()
         self.settings.connect("changed::sources", self.act_on_gsettingschange)
+
+        # Use dbus connection to check for the screensaver activity
+        self.bus = dbus.SessionBus()
+        self.session = self.bus.get_object("org.gnome.ScreenSaver", "/")
+
         # thread
         GObject.threads_init()
         # thread
@@ -162,11 +171,8 @@ class KeyboardAutoSwitchApplet(Budgie.Applet):
             return " ".join(lang)
 
     def lockscreen_check(self):
-        lockproc = "gnome-screensaver-dialog"
-        try:
-            return lockproc in (p.name() for p in psutil.process_iter())
-        except psutil.NoSuchProcess:
-            return False
+        val = self.session.get_dbus_method('GetActive')
+        return val()
 
     def change_ondeflang_select(self, widget):
         """
