@@ -1,7 +1,10 @@
 #!/bin/bash
 set -e
 
-VERSION="0.10.1"
+git submodule init
+git submodule update
+
+VERSION="0.92.0"
 NAME="budgie-extras"
 git-archive-all.sh --format tar --prefix ${NAME}-${VERSION}/ --verbose -t HEAD ${NAME}-${VERSION}.tar
 xz -9 "${NAME}-${VERSION}.tar"
